/* -------------------------------------------------------
                         blink_duo.c

     Demoprogramm fuer erstes Lebenszeichen des MCU

     MCU   :  STM8S103F3
     Takt  :  interner Takt 16 MHz

     03.02.2020  R. Seelig
   ------------------------------------------------------ */

/*
##################################################################
                         STM8S103 Pinout
##################################################################

                            STM8S103F3P6
                            ------------
UART1_CK / TIM2_CH1 / PD4  |  1     20  |  PD3 / AIN4 / TIM2_CH2 / ADC_ETR
    UART1_TX / AIN5 / PD5  |  2     19  |  PD2 / AIN3
    UART1_RX / AIN6 / PD6  |  3     18  |  PD1 / SWIM
                     NRST  |  4     17  |  PC7 / SPI_MISO
              OSCIN / PA1  |  5     16  |  PC6 / SPI_MOSI
             OSCOUT / PA2  |  6     15  |  PC5 / SPI_CLK
                Vss (GND)  |  7     14  |  PC4 / TIM1_CH4 / CLK_CCO / AIN2
                VCAP (*1)  |  8     13  |  PC3 / TIM1_CH3 /
                Vdd (+Ub)  |  9     12  |  PB4 / I2C_SCL
           TIM2_CH3 / PA3  | 10     11  |  PB5 / I2C_SDA
                            -----------


                       RxD TxD            swim

                    7   6   5   4   3   2   1   0
                    D   D   D   D   D   D   D   D
                    P   P   P   P   P   P   P   P
                 +--------------------------------+
                 | 32  31  30  29  28  27  26  25 |
            NRST | 1                           24 | PC7
                 |    O                           |
     OSCin / PA1 | 2                           23 | PC6
                 |                                |
    OSCout / PA2 | 3                           22 | PC5
                 |                                |
        Vss(GND) | 4         STM32K103         21 | PC4
                 |                                |
        Vcap(*1) | 5                           20 | PC3
                 |                                |
        Vdd(+Ub) | 6                           19 | PC2
                 |                                |
             PA3 | 7                           18 | PC1
                 |                                |
             PF4 | 8                           17 | PE5
                 |  9  10  11  12  13  14  15  16 |
                 +--------------------------------+
                    P   P   P   P   P   P   P   P
                    B   B   B   B   B   B   B   B
                    7   6   5   4   3   2   1   0

*1 :  Ist mit mindestens 1uF gegen GND zu verschalten

*/


#include "stm8s.h"
#include "stm8_init.h"
#include "stm8_gpio.h"

#define led1       B0
#define led2       B1

// ----------------------------------------------------------------
// Praeprozessormacros um 2 Stringtexte zur weiteren Verwendung
// innerhalb des Praeprozessors  zu verknuepfen
//
// Bsp.:
//        #define ionr      A
//        #define ioport    CONC(PORT, ionr)
//
//        ioport wird nun als "PORTA" behandelt
// ----------------------------------------------------------------
#define CONC2EXP(a,b)         a ## b
#define CONC(a,b)             CONC2EXP(a, b)

#define led1_init()    CONC(P,CONC(led1,_output_init()))
#define led1_set()     CONC(P,CONC(led1,_set()))
#define led1_clr()     CONC(P,CONC(led1,_clr()))

#define led2_init()    CONC(P,CONC(led2,_output_init()))
#define led2_set()     CONC(P,CONC(led2,_set()))
#define led2_clr()     CONC(P,CONC(led2,_clr()))

#define pulsetime      1000
#define pausetime      200

/* -------------------------------------------------------
                               main
   ------------------------------------------------------- */
int main(void)
{
  sysclock_init(0);                     // erst Initialisieren mit internem RC
  delay(100);

  led1_init();
  led2_init();
  led1_clr();
  led2_clr();

  while(1)
  {
    led1_set();
    delay(pulsetime);
    led1_clr();
    delay(pausetime);
    led2_set();
    delay(pulsetime);
    led2_clr();
    delay(pausetime);
  }
}

