/* ----------------------------------------------------------
                           uart_printf.h

     Header fuer Softwaremodul fuer serielle Schnittstelle
     und reduziertem PRINTF fuer AVR-MCU. Protokoll 8N1


     MCU : STM8

     16.2.2019     R. Seelig

   ---------------------------------------------------------- */

#ifndef in_uart_printf
  #define in_uart_printf

  #include <stdint.h>
  #include <stdlib.h>
  #include <stdbool.h>
  #include <stdarg.h>

  #include "stm8s.h"
  #include "stm8_init.h"
  #include "stm8_gpio.h"


  #define echo_enable     0
  #define readint_enable  1

  extern char printfkomma;

  #define use_usart             1                           // 1 fuer STM8S103
                                                            // 2 fuer STM8S105

  #define BAUDRATE       19200

  #define uart_crlf()     { uart_putchar(0x0d); uart_putchar(0x0a); }


  /* -----------------------------------------------------------------------
                                  Prototypen
     ----------------------------------------------------------------------- */
  // UART
  void uart_init(void);
  void uart_putchar(uint8_t ch);
  #define putchar    uart_putchar

  uint8_t uart_ischar( void );
  uint8_t uart_getchar( void );
  #define getch   uart_getchar

  #if (readint_enable == 1)

    int16_t readint();

  #endif

  // PRINTF
  void putint(int16_t i, char komma);
  void hexnibbleout(uint8_t b);
  void puthex(uint16_t h);
  void my_putramstring(uint8_t *p);
  void my_printf(const char *s,...);

  #define printf                my_printf

#endif
