/* ------------------------------------------------
                      tftmono_demo.c

   Demoprogramm zur Verwendung mit
     - SSD1306 Displays (I2C und SPI Interface)
     - Nokia 5110 Displays (84x48)

   Displaytyp einstellbar in tftmono.h

   MCU   :  STM8S103 / S105
   Takt  :  externer Takt 16 MHz

   04.02.2020 by R. Seelig

  -------------------------------------------------- */

#include <stdlib.h>                             // fuer abs()
#include "stm8s.h"
#include "stm8_init.h"
#include "stm8_gpio.h"

#include "tftmono.h"
#include "my_printf.h"

#include "girl2.h"

#define printf       my_printf


/* --------------------------------------------------------
   putchar

   wird von my-printf / printf aufgerufen und hier muss
   eine Zeichenausgabefunktion angegeben sein, auf das
   printf dann schreibt !
   -------------------------------------------------------- */
void my_putchar(uint8_t ch)
{
  lcd_putchar(ch);
}


/* ------------------------------------------------------------------------
                                    MAIN
   ------------------------------------------------------------------------ */

int main(void)
{
  int i;

  sysclock_init(0);                     // zuerst System fuer internen Takt

  lcd_init();
  delay(4);
  lcd_enable();
  lcd_init();
  delay(4);
  lcd_enable();
  clrscr();

  setfont(fnt8x8);
  textsize= 0;

  fb_init(64, 4);
  while(1)
  {
    fb_clear();
    clrscr();
    line(3,3,61,29, 1);
    circle(32,16,15, 1);
    fb_show(32,2);
    delay(10);
    setfont(fnt8x8);
    gotoxy(0,1);
    printf("Mono-TFT\n\r");
    delay(2000);
    clrscr();

    fb_clear();
    fb_outtextxy(1,5, 0, "H. Welt");
    fb_outtextxy(24,13, 0, "fuer");

    #ifdef __stm8s105k4__
      fb_outtextxy(0,25, 0,"STM8S105");
    #else
      fb_outtextxy(0,25, 0,"STM8S103");
    #endif

    fb_show(32, 0);
    delay(2000);

//while(1);

    fb_clear();
    fillcircle(42,20, 11, 1);
    line(0,0, 63,31, 2);
    fb_show(32, 0);
    delay(2000);

    clrscr();
    #if (ssd1306 == 1)
      showimage(32,0, &girl2_image[0], 1);           // schwarzes Display, helle Schrift
    #else
      showimage(32,0, &girl2_image[0], 2);           // helles Display, schwarze Schrift
    #endif
    delay(2000);

  }
}
